/*
 * TypeFacer.java
 * A simple application for styling sample text.
 *
 * This application serves as the basis for JavaHelp demonstrations:
 * screen-level help, field-level help, and embedded help
 */

// ....................................... imports
import java.awt.event.*;
import java.awt.*;
import java.util.Hashtable;
import java.io.*;
import java.net.*;
import javax.swing.*;
import javax.swing.border.*;
//#1 import javax.help.*;

// ....................................... TypeFacer (frame)
 
public class TypeFacer extends JFrame {

  // JavaHelp items

//#1  HelpSet hs;
//#1  HelpBroker hb;

  // screen components

  JTextField inputField, displayField;
  JComboBox  fontChoice, foreChoice, backChoice;
  JCheckBox  boldBox, italicBox;
  JButton    showButton, clearButton;
//#1  JButton    helpButton;
//#4  JButton    qButton;

//#5  // embedded help components
//#5  JPanel helpPanel;
//#5  JHelpNavigator nav;
//#5  JHelpContentViewer viewer;

  // menu components

  JMenu     fileMenu, viewMenu;
  JMenuItem exitItem, typeItem, colorItem;
//#1  JMenu helpMenu;
//#1  JMenuItem helpItem;
//#3  JMenuItem helpItemTOC;
//#7  JMenuItem embeddedItem;

  // frame will contain a panel using the CardLayout manager

  CardLayout manager;
  JPanel cards;

  // fonts and colors for use in display box

  Hashtable fonts, colors;


  // combo box choices

  final String[] fontList =
           { "TimesRoman", "Helvetica", "Courier" };
  final String[] colorList =
           { "Black", "Red", "Green", "Yellow", "Blue", "White" };

  
  // title for each screen

  final String typefTitle = "Typeface Tester: Choose Typeface";
  final String colorTitle = "Typeface Tester: Choose Colors";


  // ....................................... constructor

  public TypeFacer() {


        // create and size a JFrame; set up content pane

    super("Typeface Tester: Choose Typeface");
//#5    //!!in next line, change "250" to "500"
    setSize(500, 250);

    JPanel contentPane = (JPanel) getContentPane();
    contentPane.setLayout(new FlowLayout());
    contentPane.setBorder(
      BorderFactory.createEmptyBorder(10,10,10,10));

    // exit the program if the user closes the window

    addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent we) {System.exit(0);}
    });

//#1     // open HelpSet, send console message
//#1     // hardcoded location: "HelpSet.hs" in "TFHelp" subdirectory
//#1 
//#1     try {
//#1       URL hsURL = new URL((new File(".")).toURL(), "TFHelp/HelpSet.hs");
//#1       hs = new HelpSet(null, hsURL);
//#1       System.out.println("Found help set at " + hsURL);
//#1     }
//#1     catch (Exception ee) {
//#1       System.out.println("HelpSet not found");
//#1       System.exit(0);
//#1     }
//#1 
//#1     // create HelpBroker from HelpSet
//#1     hb = hs.createHelpBroker();
//#1
//#1     // enable function key F1
//#1     hb.enableHelpKey(getRootPane(), "overview", hs);

    // set up top-most panel containing text-input field

    JPanel inputPanel = new JPanel(new FlowLayout());
    contentPane.add(inputPanel);

    JLabel inputLabel = new JLabel("Text");
    inputField = new JTextField("Enter some text here", 30);

    inputPanel.add(inputLabel);
    inputPanel.add(inputField);


        // set up middle panel, in which two cards will
        // be displayed: typefCard and colorCard

    manager = new CardLayout();
    cards = new JPanel(manager);
    contentPane.add(cards);

    JPanel typefCard = new JPanel(new GridLayout(2,4,5,5));
    JPanel colorCard = new JPanel(new GridLayout(2,4,5,5));

    cards.add(typefCard, "Typefaces");
    cards.add(colorCard, "Colors");


        // TypeFace card: create components

    JLabel fontLabel = new JLabel("Font", JLabel.RIGHT);
    fontChoice = new JComboBox(fontList);

    JLabel styleLabel = new JLabel("Style", JLabel.RIGHT);
    boldBox = new JCheckBox("Bold");
    italicBox = new JCheckBox("Italic");

        // TypeFace card: place components on card

        // first row
    typefCard.add(fontLabel);
    typefCard.add(fontChoice);
    typefCard.add(styleLabel);
    typefCard.add(boldBox);
        // second row (start with three empty slots)
    typefCard.add(new JLabel());
    typefCard.add(new JLabel());
    typefCard.add(new JLabel());
    typefCard.add(italicBox);

        // Colors card: create components

    JLabel foreLabel = new JLabel("Foreground", JLabel.RIGHT);
    foreChoice = new JComboBox(colorList);
    foreChoice.setSelectedIndex(0);  // initialize to "black"

    JLabel backLabel = new JLabel("Background", JLabel.RIGHT);
    backChoice = new JComboBox(colorList);
    backChoice.setSelectedIndex(5);  // initialize to "white"

        // Colors card: place components on card

        // first row
    colorCard.add(new JLabel());
    colorCard.add(foreLabel);
    colorCard.add(foreChoice);
    colorCard.add(new JLabel());
        // second row
    colorCard.add(new JLabel());
    colorCard.add(backLabel);
    colorCard.add(backChoice);
    colorCard.add(new JLabel());

        // set up styled output panel

    JPanel displayPanel = new JPanel(new FlowLayout());
    contentPane.add(displayPanel);

    displayField = new JTextField(40);
    displayField.setEditable(false);
    displayField.setFont(new Font("TimesRoman", Font.PLAIN, 16));
    displayField.setHorizontalAlignment(SwingConstants.CENTER);

        // set up button panel

    JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER, 5, 5));
    contentPane.add(buttonPanel);

    showButton = new JButton("Show");
    clearButton = new JButton("Clear");
//#1    helpButton = new JButton("Help");
//#4    qButton = new JButton(new ImageIcon("help.gif"));  // make this an Icon

    buttonPanel.add(showButton);
    buttonPanel.add(clearButton);
//#1    buttonPanel.add(helpButton);
//#4    buttonPanel.add(qButton);
    displayPanel.add(displayField);

//#5    // create an embedded help panel
//#5    helpPanel = new JPanel(new GridLayout(1,2,5,5));
//#5    //helpPanel.add(displayPanel);
//#5    
//#5    // add a content viewer
//#5    viewer = new JHelpContentViewer(hs);
//#5    viewer.setPreferredSize(new Dimension(200,220));
//#6    viewer.setCurrentID("typefaces");
//#5    
//#5    // add a navigator with a table of contents view
//#5    nav = (JHelpNavigator)
//#5      hs.getNavigatorView("TOC").createNavigator(viewer.getModel());
//#5    nav.setPreferredSize(new Dimension(200,220));
//#5    
//#5    // add the components to the layout
//#5    helpPanel.add(nav);
//#5    helpPanel.add(viewer);
//#5    contentPane.add(helpPanel);

    // set up menu structure

    fileMenu = new JMenu("File");
    exitItem = new JMenuItem("Exit");
    fileMenu.add(exitItem);

    viewMenu = new JMenu("View");
    typeItem = new JMenuItem("Typefaces");
    colorItem = new JMenuItem("Colors");
    viewMenu.add(typeItem);
    viewMenu.add(colorItem);

//#1    helpMenu = new JMenu("Help");
//#3    helpItemTOC = new JMenuItem("Contents");
//#3    helpMenu.add(helpItemTOC);
//#3    CSH.setHelpIDString(helpItemTOC, "overview");
//#3    //!!in next line, change "Contents" to "For This Screen"
//#1    helpItem = new JMenuItem("Contents...");
//#1    helpMenu.add(helpItem);

//#7    embeddedItem = new JMenuItem("Hide Embedded Help");
//#7    helpMenu.add(embeddedItem);
//#7    embeddedItem.setActionCommand("hide");

    JMenuBar menuBar = new JMenuBar();
    menuBar.add(fileMenu);
    menuBar.add(viewMenu);
//#1    menuBar.add(helpMenu);

    setJMenuBar(menuBar);

    // Fill the fonts and colors hashtables

    fonts  = new Hashtable(12);
    fonts.put("Helvetica",
              new Font("Helvetica", Font.PLAIN, 16));
    fonts.put("Helveticabold",
              new Font("Helvetica", Font.BOLD, 16));
    fonts.put("Helveticaitalic",
              new Font("Helvetica", Font.ITALIC, 16));
    fonts.put("Helveticabolditalic",
              new Font("Helvetica", Font.BOLD + Font.ITALIC, 16));
    fonts.put("TimesRoman",
              new Font("TimesRoman", Font.PLAIN, 16));
    fonts.put("TimesRomanbold",
              new Font("TimesRoman", Font.BOLD, 16));
    fonts.put("TimesRomanitalic",
              new Font("TimesRoman", Font.ITALIC, 16));
    fonts.put("TimesRomanbolditalic",
              new Font("TimesRoman", Font.BOLD + Font.ITALIC, 16));
    fonts.put("Courier",
              new Font("Courier", Font.PLAIN, 16));
    fonts.put("Courierbold",
              new Font("Courier", Font.BOLD, 16));
    fonts.put("Courieritalic",
              new Font("Courier", Font.ITALIC, 16));
    fonts.put("Courierbolditalic",
              
              
              new Font("Courier", Font.BOLD + Font.ITALIC, 16));

    colors = new Hashtable(6);
    colors.put("Black", Color.black);
    colors.put("Red", Color.red);
    colors.put("Blue", Color.blue);
    colors.put("Green", Color.green);
    colors.put("Yellow", Color.yellow);
    colors.put("White", Color.white);

    // activate the "Show" button

    showButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {

        // compute the font's name (hash key)
        String fontFace = fontChoice.getSelectedItem().toString();
        fontFace += boldBox.isSelected() ? "bold" : "";
        fontFace += italicBox.isSelected() ? "italic" : "";

        // set the font
        displayField.setFont((Font)fonts.get(fontFace));

        // set the colors
        displayField.setForeground(
          (Color) colors.get(foreChoice.getSelectedItem()));
        displayField.setBackground(
          (Color) colors.get(backChoice.getSelectedItem()));
        displayField.setText(inputField.getText());
      }
    });

    // activate the "Clear" button

    clearButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {
        displayField.setText("");
        inputField.setText("");
      }
    });

    // activate the "Exit" menu item

    exitItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {System.exit(0);}
    });

    // activate the "Typefaces" menu item

    typeItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {
        manager.show(cards, "Typefaces");
        TypeFacer.this.setTitle(typefTitle);
//#2        // configure function key F1, help button, help menu item
//#2        CSH.setHelpIDString(TypeFacer.this.getRootPane(), "typefaces");
//#2        CSH.setHelpIDString(helpItem, "typefaces");
//#2        CSH.setHelpIDString(helpButton, "typefaces");

//#6        // update the embedded help content panel
//#6        viewer.setCurrentID("typefaces");
      }
    });

    // activate the "Colors" menu item

    colorItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {
        manager.show(cards, "Colors");
        TypeFacer.this.setTitle(colorTitle);
//#2        // configure function key F1, help button, help menu item
//#2        CSH.setHelpIDString(TypeFacer.this.getRootPane(), "colors");
//#2        CSH.setHelpIDString(helpItem, "colors");
//#2        CSH.setHelpIDString(helpButton, "colors");

//#6        // update the embedded help content panel
//#6        viewer.setCurrentID("colors");
      }
    });

//#7    // activate the "Embedded Help" toggle menu item
//#7
//#7    embeddedItem.addActionListener(new ActionListener() {
//#7      public void actionPerformed(ActionEvent ae) {
//#7        if (ae.getActionCommand().equals("hide")) {
//#7          helpPanel.remove(nav);
//#7          helpPanel.remove(viewer);
//#7          helpPanel.validate();
//#7          TypeFacer.this.setSize(500,250);
//#7          embeddedItem.setText("Show Embedded Help");
//#7          embeddedItem.setActionCommand("show");
//#7        }
//#7        else {
//#7          helpPanel.add(nav);
//#7          helpPanel.add(viewer);
//#7          helpPanel.validate();
//#7          TypeFacer.this.setSize(500,500);
//#7          embeddedItem.setText("Hide Embedded Help");
//#7          embeddedItem.setActionCommand("hide");
//#7        }
//#7      }
//#7    });


//#4    // activate the field-level help button
//#4
//#4    qButton.addActionListener(
//#4      new CSH.DisplayHelpAfterTracking(hb)
//#4    );
//
//#1    // activate the Help menu item and Help button
//#1
//#1    ActionListener helper = new CSH.DisplayHelpFromSource(hb);
//#1    helpItem.addActionListener(helper);
//#1    helpButton.addActionListener(helper);
//#3    helpItemTOC.addActionListener(helper);

//#4    // assign map IDs for field-level context-sensitive help
//#4
//#4    CSH.setHelpIDString(inputField, "text");
//#4    CSH.setHelpIDString(fontChoice, "font");
//#4    CSH.setHelpIDString(boldBox, "bold");
//#4    CSH.setHelpIDString(italicBox, "italic");
//#4    CSH.setHelpIDString(showButton, "view"); 
//#4    CSH.setHelpIDString(clearButton, "clear"); 
//#4    CSH.setHelpIDString(helpButton, "help");
//#4    CSH.setHelpIDString(qButton, "whats_this");
//#4    CSH.setHelpIDString(displayField, "text_display");
//#4    CSH.setHelpIDString(foreChoice, "fore_color");
//#4    CSH.setHelpIDString(backChoice, "back_color");

  }

  public static void main(String args[]) {
    (new TypeFacer()).setVisible(true);
  }
}
